# Generated by Django 3.0.3 on 2020-03-12 08:54

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('main', '0007_auto_20200304_1915'),
    ]

    operations = [
        migrations.CreateModel(
            name='ConfigurationModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('train_percentage', models.IntegerField(default=80, validators=[django.core.validators.MaxValueValidator(100), django.core.validators.MinValueValidator(1)])),
                ('test_percentage', models.IntegerField(default=20)),
            ],
        ),
        migrations.CreateModel(
            name='ImageDetectionModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('image', models.ImageField(upload_to='uploaded')),
                ('stat', models.TextField()),
            ],
        ),
        migrations.RenameModel(
            old_name='YoloClass',
            new_name='YoloClassModel',
        ),
    ]
