# Generated by Django 3.0.3 on 2020-03-02 17:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('main', '0004_auto_20200302_1703'),
    ]

    operations = [
        migrations.AlterField(
            model_name='dontfakeme',
            name='image',
            field=models.ImageField(upload_to='static/images/'),
        ),
    ]
