# Generated by Django 3.0.3 on 2020-02-27 15:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('main', '0002_auto_20200225_1930'),
    ]

    operations = [
        migrations.CreateModel(
            name='AnnotationImageModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('image', models.FileField(upload_to='media/darknet/data/custom')),
                ('annotate', models.FileField(upload_to='media/darknet/data/custom')),
            ],
        ),
        migrations.RemoveField(
            model_name='objectclassmodel',
            name='user',
        ),
        migrations.DeleteModel(
            name='AnnotationClass',
        ),
        migrations.DeleteModel(
            name='ObjectClassModel',
        ),
    ]
