# Generated by Django 3.0.3 on 2020-03-04 19:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('main', '0006_auto_20200304_1910'),
    ]

    operations = [
        migrations.AlterField(
            model_name='yoloclass',
            name='name',
            field=models.CharField(max_length=30, unique=True),
        ),
    ]
